@@ -24,8 +24,8 @@
 #include "startapphtml.h"
 
 int
-startapp4html( int argc, char * argv[], char *prog_name, char *prog_ver )
+startapp4html( int argc, char * argv[] )
 {
-  StartAppHtml start_app (prog_name, prog_ver);
+  StartAppHtml start_app;
   return start_app.start (argc, argv);
 }
