@@ -29,9 +29,6 @@ class StartAppHtml : public StartApp
  protected:
   // factory method
   virtual CharTranslator *createCharTranslator();
-
- public:
-  StartAppHtml(char *prog_name, char *prog_ver);
 } ;
 
 #endif /* _STARTAPPHTML_H */
