@@ -38,11 +38,21 @@ CharTranslator::set_translation(char to_translate,
 void
 CharTranslator::translate(ostream *sout, const char *s)
 {
+  unsigned char current;
   for (unsigned int i = 0; i < strlen (s); ++i)
     {
-      if (characters[s[i]])
-        (*sout) << characters[s[i]];
+      current = ((unsigned char)(s[i]));
+      if (characters[current])
+        (*sout) << characters[current];
       else
         (*sout) << s[i];
     }
 }
+
+/*
+  The cast to unsigned char for s[i] is necessary for
+  foreign characters such as  (before it used to seg.fault;  thanks to
+  Martin Gebert <Murphy.Gebert@gmx.de> for notifying me
+  about this problem).  Being an Italian who does not speak German
+  I never experienced such a problem ;-)
+*/
