@@ -18,7 +18,7 @@ extern TextGenerator *SymbolGenerator ;
 extern TextGenerator *FunctionGenerator ;
 extern TextGenerator *CBracketGenerator ;
 
-extern void createGenerators(CharTranslator *) ;
-extern void createGeneratorsForCSS(CharTranslator *) ;
+extern void createGenerators(CharTranslator *, int) ;
+extern void createGeneratorsForCSS(CharTranslator *, int) ;
 
 #endif
