@@ -32,6 +32,7 @@
 #include "textgen.h"
 #include "decorators.h"
 #include "fileutil.h"
+#include "linenogen.h"
 
 // globals
 #include "linenumdigit.h"
@@ -45,6 +46,7 @@ extern int java_scanner_lex() ;
 extern int cpp_scanner_lex() ;
 extern int prolog_scanner_lex() ;
 extern int perl_scanner_lex() ;
+extern int php3_scanner_lex() ;
 
 extern int tabSpaces; // FIXME
 
@@ -81,6 +83,11 @@ processFile( char *source_language,
           lines /= 10;
         }
     }
+  else
+    line_num_digit = 5;
+  // if we read from stdin, we can't read the file in advance and
+  // check how many lines of code it contains.  In this case set
+  // the number of digit for the line number to 5.
 
   if (inputFileName)
     {
@@ -121,6 +128,8 @@ processFile( char *source_language,
   _generateln( "<pre>" ) ;
   _generateln( "<tt>" ) ;
 
+  LineNumberDecorator::reset ();
+
   // decide which lexer to call
   if (strcmp (source_language, "java") == 0)
     java_scanner_lex () ;
@@ -130,6 +139,8 @@ processFile( char *source_language,
     prolog_scanner_lex ();
   else if (strcmp (source_language, "perl") == 0)
     perl_scanner_lex ();
+  else if (strcmp (source_language, "php3") == 0)
+    php3_scanner_lex ();
   else
     {
       cerr << PACKAGE << ": ";
