@@ -26,14 +26,13 @@ extern char *inputFileName ; /* what we're reading  */
 extern ostream* sout ;
 
 char *createOutputFileName( char *inputFileName ) ;
-void processFile( char *progname, char *version,
+void processFile( char *source_language,
                   char *inputFileName, char *outputFileName, char *docTitle,
                   const char *docHeader, const char *docFooter,
                   short entire_doc, char *cssUrl ) ;
 char *getCodeLine( void ) ;
 void print_cgi_header();
-void print_top( char *progname, char *version, 
-                char *docTitle, char *s , const char *docHeader,
+void print_top( char *docTitle, char *s , const char *docHeader,
                 char *inputFileName) ;
 void print_bottom( const char *docFooter ) ;
 void generate( const char *s ) ;
