@@ -33,18 +33,15 @@ class StartApp
   int use_css; // Use CSS instead of font-tags
   int is_cgi;   // set if in CGI mode (and therefore has to add CGI-header)
   
-  char *programName;
-  char *programVersion;
-
   virtual void print_copyright();
   virtual void print_reportbugs();
-  virtual void print_version(char *progname, char *progversion);
+  virtual void print_version();
 
   // factory method
   virtual CharTranslator *createCharTranslator() = 0;
 
  public:
-  StartApp(char *prog_name, char *prog_ver);
+  StartApp();
 
   virtual int start(int argc, char * argv[]);
 } ;
